--------------------------------------------------------------------------------
--
-- Title       : Scanner FPGA
-- Design      : Decoder_InxOut
-- Author      : Alex Shtengel
-- Company     : Home
--------------------------------------------------------------------------------
-- File        : Decoder_InxOut.vhd
-- Generated   : Mar 21  2015
--------------------------------------------------------------------------------
-- Description : Decoder
--------------------------------------------------------------------------------
-- Revision History :
-- -----------------------------------------------------------------------------
--   Ver  :| Author            :| Mod. Date :|    Changes Made:
--   v1.0  | Alex Shtengel	   :| 21/03/15	:| Automatically Generated
-- -----------------------------------------------------------------------------

library ieee;
use ieee.std_logic_1164.all;
use ieee.std_logic_unsigned.all;
use ieee.std_logic_arith.all;

entity Decoder_InxOut is
GENERIC (InputLength,OutLength	: integer);
port
(
 ClockIn 		: in	std_logic; 																										-- General clock
 nResetIn		: in	std_logic; 																										-- General Reset active High
 Input 			: in	std_logic_vector(InputLength downto 0);												-- Input number for decoding
 OutputSel  : out	std_logic_vector(OutLength downto 0)    											-- Outputs
);
end Decoder_InxOut;

architecture ArchDecoder_InxOut of Decoder_InxOut is
	signal InputTemp  		: integer range 0 to OutLength + 1;
begin

InputTemp <= conv_integer(Input);

DecProcess:
process(ClockIn)
begin
 if (ClockIn = '1' and ClockIn'event) then
	case nResetIn is
	 when '0' =>
  	ResetLoop:
  	for i in OutLength downto 0 loop
	 	 OutputSel(i) <= '0';
  	end loop ResetLoop;

	 when others =>

		DecLoop:
  	for i in OutLength downto 0 loop
	 	 if InputTemp = i then
	    OutputSel(i) <= '1';
	 	 else
	    OutputSel(i) <= '0';
	 	 end if;
  	end loop DecLoop;
	end case;
 end if ;
end process	DecProcess;

end ArchDecoder_InxOut;

